@@ -19,7 +19,7 @@
 
 lakeSurfaceArea <- function(inLakeMorpho) {
     if (class(inLakeMorpho) != "lakeMorpho") {
-        return(warning("Input data is not of class 'lakeMorpho'.  Run lakeSurround Topo first."))
+      stop("Input data is not of class 'lakeMorpho'.  Run lakeSurround Topo or lakeMorphoClass first.")
     }
     return(gArea(inLakeMorpho$lake))
 } 
